#
# spec file for package canutils
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           canutils
%define lname   libisobusfs-suse0
Version:        2025.01
Release:        1.1
Summary:        Utilities for Controller Area Networks from the Linux-CAN project
License:        BSD-3-Clause AND GPL-2.0-only AND LGPL-2.0-only
Group:          Hardware/Other
URL:            https://github.com/linux-can/can-utils
Source:         https://github.com/linux-can/can-utils/archive/refs/tags/v%version.tar.gz
Patch1:         0001-build-give-libisobusfs-a-version.patch
BuildRequires:  cmake >= 3.5
BuildRequires:  pkg-config
BuildRequires:  xz
Obsoletes:      canutils-linuxcan
Provides:       can-utils = %version-%release
Provides:       canutils-linuxcan

%description
SocketCAN userspace utilities and tools.

CAN is a message-based network protocol designed for vehicles
originally initially created by Robert Bosch GmbH. SocketCAN is a set
of CAN drivers and a networking stack contributed by Volkswagen
Research to the Linux kernel.

This package contains some userspace utilities for the Linux
SocketCAN subsystem.

%package -n libisobusfs0
Summary:        Component library for can-utils
Group:          System/Libraries
License:        LGPL-2.0-only

%description -n libisobusfs0
Component library for the CAN utilities.

%prep
%autosetup -n can-utils-%version -p1

%build
%cmake
%cmake_build

%install
%cmake_install
# headers are useless at present - https://github.com/linux-can/can-utils/issues/578
rm -Rf "%buildroot/%_includedir" "%buildroot/%_libdir/libisobusfs.so"

%ldconfig_scriptlets -n libisobusfs0

%files
%doc *.md
%license LICENSES/*
%_bindir/*

%files -n libisobusfs0
%_libdir/libisobusfs.so.*

%changelog
* Tue Feb 18 2025 Jan Engelhardt <jengelh@inai.de>
- Add 0001-build-give-libisobusfs-a-version.patch
* Mon Feb 10 2025 pgajdos@suse.com
- version update to 2025.01
  * Support of new kernel features:
  * Full CAN XL support for candump, canplayer, cangen, log2asc,
    asc2log, lib
  * cangen: support socket priority
  * Improvements and features:
  * ISOBUS (ISO11783-13) File Server Interface (isobusfs-srv,
    isobusfs-cli)
  * Add j1939_datatime_cli
  * cansequence: allow to bind on "any" interface
  * cansequence: add support to send and receive CAN-FD
  * canfdtest: add support for loopback testing
  * isotpdump: option to capture functional addressing traffic
  * isotpdump: add color support for functional addressing traffic
  * isotprecv: add option to enable dynamic flow control
    parameters (Linux 6.9+)
  * cangen: add missing long CAN frame view for len8_dlc and eff
  * canbusload: add auto detection of CAN interfaces
  * canbusload: show RX/TX direction in bargraph
  * canbusload: support busload statistic and busload visualization
* Wed Mar 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2023.03
  * cangen: add support for SO_TXTIME
  * canfdtest: Add extended frame format / message length / FD /
    BRS support
  * can-calc-bit-timing: add support for calculation of CAN-FD
    bit timings
  * cangen: new generation mode - partially randomized payload
    (-D)
  * cansniffer: add CAN FD support
* Thu Aug 19 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2021.08.0
  * Support for new kernel features:
  * Add len8_dlc support for Classical CAN frames (Linux v5.11+)
  * Add ISOTP SF_BROADCAST support (Linux v5.11+)
* Tue Dec 29 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.12.0
  * candump: Enable zero relative timestamps to be used in
    log files.
  * "-tz" and "-ta" are now valid options for the logfile format.
* Mon Nov 30 2020 Jan Engelhardt <jengelh@inai.de>
- Add "can-utils" provides, add documentation.
* Tue Nov 17 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.11.0
  * No further changes to prior snapshot, just version bump.
* Thu Oct 29 2020 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 2020.04.02.g192 (4573e852f9)
  * isotpsend: add support for blocking write flag
  * add cansequence tool
* Tue Sep  1 2020 Jan Engelhardt <jengelh@inai.de>
- Update to version 2020.04.02.g119 (ea844bdc5e)
  * Rename jcat et al to j1939cat
  * j1939cat: add broadcast support
* Mon Aug 24 2020 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to version v2020.04.02
  * jcat: provide errqueue support
  * jcat: add repeat support
  * Add uds output functionality
  * cangw: add new command line option -X to handle CAN FD rules
  * cangw: add CAN FD support
- Drop 0001-fix-include-to-find-SIOCGSTAMP-with-latest-kernel.patch
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Add 0001-fix-include-to-find-SIOCGSTAMP-with-latest-kernel.patch
  to unbreak build with modern linux-glibc-devel.
* Sat Aug 25 2018 jengelh@inai.de
- Rename canutils-linuxcan to canutils
* Wed Aug 15 2018 tuukka.pasanen@ilmi.fi
- Update to official release 2018.02.0
* Mon Nov 21 2016 jengelh@inai.de
- Initial package (version 0~g296) for build.opensuse.org
